
.. _`CIM objects`:

CIM objects
-----------

.. automodule:: pywbem.cim_obj

.. _`NocaseDict`:

NocaseDict
^^^^^^^^^^

.. automodule:: pywbem._nocasedict

CIMInstanceName
^^^^^^^^^^^^^^^

.. autoclass:: pywbem.CIMInstanceName
   :members:
   :exclude-members: __hash__

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMInstanceName
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMInstanceName
      :attributes:

   .. rubric:: Details

CIMInstance
^^^^^^^^^^^

.. autoclass:: pywbem.CIMInstance
   :members:
   :exclude-members: __hash__

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMInstance
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMInstance
      :attributes:

   .. rubric:: Details

CIMClassName
^^^^^^^^^^^^

.. autoclass:: pywbem.CIMClassName
   :members:
   :exclude-members: __hash__

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMClassName
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMClassName
      :attributes:

   .. rubric:: Details

CIMClass
^^^^^^^^

.. autoclass:: pywbem.CIMClass
   :members:
   :exclude-members: __hash__

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMClass
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMClass
      :attributes:

   .. rubric:: Details

CIMProperty
^^^^^^^^^^^

.. autoclass:: pywbem.CIMProperty
   :members:
   :exclude-members: __hash__

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMProperty
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMProperty
      :attributes:

   .. rubric:: Details

CIMMethod
^^^^^^^^^

.. autoclass:: pywbem.CIMMethod
   :members:
   :exclude-members: __hash__

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMMethod
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMMethod
      :attributes:

   .. rubric:: Details

CIMParameter
^^^^^^^^^^^^

.. autoclass:: pywbem.CIMParameter
   :members:
   :exclude-members: __hash__

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMParameter
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMParameter
      :attributes:

   .. rubric:: Details

CIMQualifier
^^^^^^^^^^^^

.. autoclass:: pywbem.CIMQualifier
   :members:
   :exclude-members: __hash__

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMQualifier
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMQualifier
      :attributes:

   .. rubric:: Details

CIMQualifierDeclaration
^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: pywbem.CIMQualifierDeclaration
   :members:
   :exclude-members: __hash__

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMQualifierDeclaration
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMQualifierDeclaration
      :attributes:

   .. rubric:: Details
